!/**
 * Highcharts Gantt JS v11.4.8 (2024-08-29)
 *
 * StaticScale
 *
 * (c) 2016-2024 Torstein Honsi, Lars A. V. Cabrera
 *
 * License: www.highcharts.com/license
 */function(t){"object"==typeof module&&module.exports?(t.default=t,module.exports=t):"function"==typeof define&&define.amd?define("highcharts/modules/static-scale",["highcharts"],function(e){return t(e),t.Highcharts=e,t}):t("undefined"!=typeof Highcharts?Highcharts:void 0)}(function(t){"use strict";var e=t?t._modules:{};function i(e,i,s,a){e.hasOwnProperty(i)||(e[i]=a.apply(null,s),"function"==typeof CustomEvent&&t.win.dispatchEvent(new CustomEvent("HighchartsModuleLoaded",{detail:{path:i,module:e[i]}})))}i(e,"Extensions/StaticScale.js",[e["Core/Utilities.js"]],function(t){let{addEvent:e,defined:i,isNumber:s,pick:a}=t;function o(){let t=this.chart.options.chart;!this.horiz&&s(this.options.staticScale)&&(!t.height||t.scrollablePlotArea&&t.scrollablePlotArea.minHeight)&&(this.staticScale=this.options.staticScale)}function n(){if("adjustHeight"!==this.redrawTrigger){for(let t of this.axes||[]){let e=t.chart,s=!!e.initiatedScale&&e.options.animation,o=t.options.staticScale;if(t.staticScale&&i(t.min)){let i=a(t.brokenAxis&&t.brokenAxis.unitLength,t.max+t.tickInterval-t.min)*o,n=(i=Math.max(i,o))-e.plotHeight;!e.scrollablePixelsY&&Math.abs(n)>=1&&(e.plotHeight=i,e.redrawTrigger="adjustHeight",e.setSize(void 0,e.chartHeight+n,s)),t.series.forEach(function(t){let i=t.sharedClipKey&&e.sharedClips[t.sharedClipKey];i&&i.attr(e.inverted?{width:e.plotHeight}:{height:e.plotHeight})})}}this.initiatedScale=!0}this.redrawTrigger=null}return{compose:function(t,i){let s=i.prototype;s.adjustHeight||(e(t,"afterSetOptions",o),s.adjustHeight=n,e(i,"render",s.adjustHeight))}}}),i(e,"masters/modules/static-scale.src.js",[e["Core/Globals.js"],e["Extensions/StaticScale.js"]],function(t,e){return e.compose(t.Axis,t.Chart),t})});