!/**
 * Highcharts JS v11.4.8 (2024-08-29)
 *
 * Dot plot series type for Highcharts
 *
 * (c) 2010-2024 Torstein Honsi
 *
 * License: www.highcharts.com/license
 */function(t){"object"==typeof module&&module.exports?(t.default=t,module.exports=t):"function"==typeof define&&define.amd?define("highcharts/modules/dotplot",["highcharts"],function(e){return t(e),t.Highcharts=e,t}):t("undefined"!=typeof Highcharts?Highcharts:void 0)}(function(t){"use strict";var e=t?t._modules:{};function s(e,s,i,o){e.hasOwnProperty(s)||(e[s]=o.apply(null,i),"function"==typeof CustomEvent&&t.win.dispatchEvent(new CustomEvent("HighchartsModuleLoaded",{detail:{path:s,module:e[s]}})))}s(e,"Series/DotPlot/DotPlotSeriesDefaults.js",[],function(){return{itemPadding:.1,marker:{symbol:"circle",states:{hover:{},select:{}}},slotsPerBar:void 0}}),s(e,"Series/DotPlot/DotPlotSeries.js",[e["Series/DotPlot/DotPlotSeriesDefaults.js"],e["Core/Series/SeriesRegistry.js"],e["Core/Utilities.js"]],function(t,e,s){let{column:i}=e.seriesTypes,{extend:o,isNumber:r,merge:l,pick:n}=s;class a extends i{drawPoints(){let t=this.options,e=this.chart.renderer,s=t.marker,i=this.points.reduce((t,e)=>t+Math.abs(e.y||0),0),l=this.points.reduce((t,e)=>t+(e.shapeArgs?.height||0),0),a=t.itemPadding||0,d=this.points[0]?.shapeArgs?.width||0,h=t.slotsPerBar,c=d;if(!r(h))for(h=1;h<i&&!(i/h<l/c*1.2);)c=d/++h;let p=l*h/i;for(let t of this.points){let i=t.marker||{},r=i.symbol||s.symbol,l=n(i.radius,s.radius),d="rect"!==r?p:c,u=t.shapeArgs||{},f=(u.x||0)+((u.width||0)-h*d)/2,g=Math.abs(t.y??0),m=u.y||0,y=u.height||0,v,P=f,b=t.negative?m:m+y-p,A=0;t.graphics=v=t.graphics||[];let S=t.pointAttr?t.pointAttr[t.selected?"selected":""]||this.pointAttr[""]:this.pointAttribs(t,t.selected&&"select");if(delete S.r,this.chart.styledMode&&(delete S.stroke,delete S["stroke-width"]),"number"==typeof t.y){t.graphic||(t.graphic=e.g("point").add(this.group));for(let s=0;s<g;s++){let i={x:P+d*a,y:b+p*a,width:d*(1-2*a),height:p*(1-2*a),r:l},n=v[s];n?n.animate(i):n=e.symbol(r).attr(o(i,S)).add(t.graphic),n.isActive=!0,v[s]=n,P+=d,++A>=h&&(A=0,P=f,b=t.negative?b+p:b-p)}}let j=-1;for(let t of v)++j,t&&(t.isActive?t.isActive=!1:(t.destroy(),v.splice(j,1)))}}}return a.defaultOptions=l(i.defaultOptions,t),o(a.prototype,{markerAttribs:void 0}),e.registerSeriesType("dotplot",a),a}),s(e,"masters/modules/dotplot.src.js",[e["Core/Globals.js"]],function(t){return t})});